*******
patches
*******


:mod:`matplotlib.patches`
=========================

.. currentmodule:: matplotlib.patches

.. automodule:: matplotlib.patches
   :no-members:
   :no-inherited-members:

Classes
-------

.. autosummary::
   :toctree: _as_gen/
   :template: autosummary.rst

   Arc
   Arrow
   ArrowStyle
   BoxStyle
   Circle
   CirclePolygon
   ConnectionPatch
   ConnectionStyle
   Ellipse
   FancyArrow
   FancyArrowPatch
   FancyBboxPatch
   Patch
   PathPatch
   Polygon
   Rectangle
   RegularPolygon
   Shadow
   Wedge
   YAArrow

Functions
---------

.. autosummary::
   :toctree: _as_gen/
   :template: autosummary.rst

   bbox_artist
   draw_bbox
   
